@@ -1,7 +1,7 @@
 // ASResource.cpp
-// Copyright (c) 2016 by Jim Pattee <jimp03@email.com>.
+// Copyright (c) 2017 by Jim Pattee <jimp03@email.com>.
 // This code is licensed under the MIT License.
-// License.txt describes the conditions under which this software may be distributed.
+// License.md describes the conditions under which this software may be distributed.
 
 //-----------------------------------------------------------------------------
 // headers
@@ -36,6 +36,7 @@ const string ASResource::AS_ELSE = string("else");
 const string ASResource::AS_END = string("end");
 const string ASResource::AS_ENUM = string("enum");
 const string ASResource::AS_EXTERN = string("extern");
+const string ASResource::AS_FINAL = string("final");
 const string ASResource::AS_FINALLY = string("finally");
 const string ASResource::AS_FIXED = string("fixed");
 const string ASResource::AS_FOR = string("for");
@@ -185,24 +186,33 @@ bool sortOnName(const string* a, const string* b)
  */
 void ASResource::buildAssignmentOperators(vector<const string*>* assignmentOperators)
 {
-	assignmentOperators->push_back(&AS_ASSIGN);
-	assignmentOperators->push_back(&AS_PLUS_ASSIGN);
-	assignmentOperators->push_back(&AS_MINUS_ASSIGN);
-	assignmentOperators->push_back(&AS_MULT_ASSIGN);
-	assignmentOperators->push_back(&AS_DIV_ASSIGN);
-	assignmentOperators->push_back(&AS_MOD_ASSIGN);
-	assignmentOperators->push_back(&AS_OR_ASSIGN);
-	assignmentOperators->push_back(&AS_AND_ASSIGN);
-	assignmentOperators->push_back(&AS_XOR_ASSIGN);
+	const size_t elements = 15;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		assignmentOperators->reserve(elements);
+		reserved = true;
+	}
+
+	assignmentOperators->emplace_back(&AS_ASSIGN);
+	assignmentOperators->emplace_back(&AS_PLUS_ASSIGN);
+	assignmentOperators->emplace_back(&AS_MINUS_ASSIGN);
+	assignmentOperators->emplace_back(&AS_MULT_ASSIGN);
+	assignmentOperators->emplace_back(&AS_DIV_ASSIGN);
+	assignmentOperators->emplace_back(&AS_MOD_ASSIGN);
+	assignmentOperators->emplace_back(&AS_OR_ASSIGN);
+	assignmentOperators->emplace_back(&AS_AND_ASSIGN);
+	assignmentOperators->emplace_back(&AS_XOR_ASSIGN);
 
 	// Java
-	assignmentOperators->push_back(&AS_GR_GR_GR_ASSIGN);
-	assignmentOperators->push_back(&AS_GR_GR_ASSIGN);
-	assignmentOperators->push_back(&AS_LS_LS_ASSIGN);
+	assignmentOperators->emplace_back(&AS_GR_GR_GR_ASSIGN);
+	assignmentOperators->emplace_back(&AS_GR_GR_ASSIGN);
+	assignmentOperators->emplace_back(&AS_LS_LS_ASSIGN);
 
 	// Unknown
-	assignmentOperators->push_back(&AS_LS_LS_LS_ASSIGN);
+	assignmentOperators->emplace_back(&AS_LS_LS_LS_ASSIGN);
 
+	assert(assignmentOperators->size() < elements);
 	sort(assignmentOperators->begin(), assignmentOperators->end(), sortOnLength);
 }
 
@@ -214,10 +224,21 @@ void ASResource::buildAssignmentOperators(vector<const string*>* assignmentOpera
  */
 void ASResource::buildCastOperators(vector<const string*>* castOperators)
 {
-	castOperators->push_back(&AS_CONST_CAST);
-	castOperators->push_back(&AS_DYNAMIC_CAST);
-	castOperators->push_back(&AS_REINTERPRET_CAST);
-	castOperators->push_back(&AS_STATIC_CAST);
+	const size_t elements = 5;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		castOperators->reserve(elements);
+		reserved = true;
+	}
+
+	castOperators->emplace_back(&AS_CONST_CAST);
+	castOperators->emplace_back(&AS_DYNAMIC_CAST);
+	castOperators->emplace_back(&AS_REINTERPRET_CAST);
+	castOperators->emplace_back(&AS_STATIC_CAST);
+
+	assert(castOperators->size() < elements);
+	sort(castOperators->begin(), castOperators->end(), sortOnName);
 }
 
 /**
@@ -228,57 +249,67 @@ void ASResource::buildCastOperators(vector<const string*>* castOperators)
  */
 void ASResource::buildHeaders(vector<const string*>* headers, int fileType, bool beautifier)
 {
-	headers->push_back(&AS_IF);
-	headers->push_back(&AS_ELSE);
-	headers->push_back(&AS_FOR);
-	headers->push_back(&AS_WHILE);
-	headers->push_back(&AS_DO);
-	headers->push_back(&AS_SWITCH);
-	headers->push_back(&AS_CASE);
-	headers->push_back(&AS_DEFAULT);
-	headers->push_back(&AS_TRY);
-	headers->push_back(&AS_CATCH);
-	headers->push_back(&AS_QFOREACH);		// QT
-	headers->push_back(&AS_QFOREVER);		// QT
-	headers->push_back(&AS_FOREACH);		// QT & C#
-	headers->push_back(&AS_FOREVER);		// Qt & Boost
+	const size_t elements = 25;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		headers->reserve(elements);
+		reserved = true;
+	}
+
+	headers->emplace_back(&AS_IF);
+	headers->emplace_back(&AS_ELSE);
+	headers->emplace_back(&AS_FOR);
+	headers->emplace_back(&AS_WHILE);
+	headers->emplace_back(&AS_DO);
+	headers->emplace_back(&AS_SWITCH);
+	headers->emplace_back(&AS_CASE);
+	headers->emplace_back(&AS_DEFAULT);
+	headers->emplace_back(&AS_TRY);
+	headers->emplace_back(&AS_CATCH);
+	headers->emplace_back(&AS_QFOREACH);		// QT
+	headers->emplace_back(&AS_QFOREVER);		// QT
+	headers->emplace_back(&AS_FOREACH);		// QT & C#
+	headers->emplace_back(&AS_FOREVER);		// Qt & Boost
 
 	if (fileType == C_TYPE)
 	{
-		headers->push_back(&_AS_TRY);		// __try
-		headers->push_back(&_AS_FINALLY);	// __finally
-		headers->push_back(&_AS_EXCEPT);	// __except
+		headers->emplace_back(&_AS_TRY);		// __try
+		headers->emplace_back(&_AS_FINALLY);	// __finally
+		headers->emplace_back(&_AS_EXCEPT);	// __except
 	}
 	if (fileType == JAVA_TYPE)
 	{
-		headers->push_back(&AS_FINALLY);
-		headers->push_back(&AS_SYNCHRONIZED);
+		headers->emplace_back(&AS_FINALLY);
+		headers->emplace_back(&AS_SYNCHRONIZED);
 	}
 
 	if (fileType == SHARP_TYPE)
 	{
-		headers->push_back(&AS_FINALLY);
-		headers->push_back(&AS_LOCK);
-		headers->push_back(&AS_FIXED);
-		headers->push_back(&AS_GET);
-		headers->push_back(&AS_SET);
-		headers->push_back(&AS_ADD);
-		headers->push_back(&AS_REMOVE);
-		headers->push_back(&AS_USING);
+		headers->emplace_back(&AS_FINALLY);
+		headers->emplace_back(&AS_LOCK);
+		headers->emplace_back(&AS_FIXED);
+		headers->emplace_back(&AS_GET);
+		headers->emplace_back(&AS_SET);
+		headers->emplace_back(&AS_ADD);
+		headers->emplace_back(&AS_REMOVE);
+		headers->emplace_back(&AS_USING);
 	}
 
 	if (beautifier)
 	{
 		if (fileType == C_TYPE)
 		{
-			headers->push_back(&AS_TEMPLATE);
+			headers->emplace_back(&AS_TEMPLATE);
 		}
 
 		if (fileType == JAVA_TYPE)
 		{
-			headers->push_back(&AS_STATIC);         // for static constructor
+			headers->emplace_back(&AS_STATIC);         // for static constructor
 		}
 	}
+
+	assert(headers->size() < elements);
 	sort(headers->begin(), headers->end(), sortOnName);
 }
 
@@ -290,9 +321,9 @@ void ASResource::buildHeaders(vector<const string*>* headers, int fileType, bool
  */
 void ASResource::buildIndentableHeaders(vector<const string*>* indentableHeaders)
 {
-	indentableHeaders->push_back(&AS_RETURN);
+	indentableHeaders->emplace_back(&AS_RETURN);
 
-	sort(indentableHeaders->begin(), indentableHeaders->end(), sortOnName);
+//	sort(indentableHeaders->begin(), indentableHeaders->end(), sortOnName);
 }
 
 /**
@@ -303,24 +334,33 @@ void ASResource::buildIndentableHeaders(vector<const string*>* indentableHeaders
 */
 void ASResource::buildIndentableMacros(vector<const pair<const string, const string>* >* indentableMacros)
 {
-	typedef pair<const string, const string> macro_pair;
+	const size_t elements = 10;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		indentableMacros->reserve(elements);
+		reserved = true;
+	}
 
 	// the pairs must be retained in memory because of pair pointers
+	typedef pair<const string, const string> macro_pair;
 	static const macro_pair macros[] =
 	{
 		// wxWidgets
-		macro_pair("BEGIN_EVENT_TABLE", "END_EVENT_TABLE"),
+		macro_pair("BEGIN_EVENT_TABLE",   "END_EVENT_TABLE"),
 		macro_pair("wxBEGIN_EVENT_TABLE", "wxEND_EVENT_TABLE"),
 		// MFC
-		macro_pair("BEGIN_DISPATCH_MAP", "END_DISPATCH_MAP"),
-		macro_pair("BEGIN_EVENT_MAP", "END_EVENT_MAP"),
-		macro_pair("BEGIN_MESSAGE_MAP", "END_MESSAGE_MAP"),
-		macro_pair("BEGIN_PROPPAGEIDS", "END_PROPPAGEIDS"),
+		macro_pair("BEGIN_DISPATCH_MAP",  "END_DISPATCH_MAP"),
+		macro_pair("BEGIN_EVENT_MAP",     "END_EVENT_MAP"),
+		macro_pair("BEGIN_MESSAGE_MAP",   "END_MESSAGE_MAP"),
+		macro_pair("BEGIN_PROPPAGEIDS",   "END_PROPPAGEIDS"),
 	};
 
-	size_t elements = sizeof(macros) / sizeof(macros[0]);
-	for (size_t i = 0; i < elements; i++)
-		indentableMacros->push_back(&macros[i]);
+	size_t entries = sizeof(macros) / sizeof(macros[0]);
+	for (size_t i = 0; i < entries; i++)
+		indentableMacros->emplace_back(&macros[i]);
+
+	assert(indentableMacros->size() < elements);
 }
 
 /**
@@ -331,21 +371,30 @@ void ASResource::buildIndentableMacros(vector<const pair<const string, const str
  */
 void ASResource::buildNonAssignmentOperators(vector<const string*>* nonAssignmentOperators)
 {
-	nonAssignmentOperators->push_back(&AS_EQUAL);
-	nonAssignmentOperators->push_back(&AS_PLUS_PLUS);
-	nonAssignmentOperators->push_back(&AS_MINUS_MINUS);
-	nonAssignmentOperators->push_back(&AS_NOT_EQUAL);
-	nonAssignmentOperators->push_back(&AS_GR_EQUAL);
-	nonAssignmentOperators->push_back(&AS_GR_GR_GR);
-	nonAssignmentOperators->push_back(&AS_GR_GR);
-	nonAssignmentOperators->push_back(&AS_LS_EQUAL);
-	nonAssignmentOperators->push_back(&AS_LS_LS_LS);
-	nonAssignmentOperators->push_back(&AS_LS_LS);
-	nonAssignmentOperators->push_back(&AS_ARROW);
-	nonAssignmentOperators->push_back(&AS_AND);
-	nonAssignmentOperators->push_back(&AS_OR);
-	nonAssignmentOperators->push_back(&AS_LAMBDA);
+	const size_t elements = 15;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		nonAssignmentOperators->reserve(elements);
+		reserved = true;
+	}
 
+	nonAssignmentOperators->emplace_back(&AS_EQUAL);
+	nonAssignmentOperators->emplace_back(&AS_PLUS_PLUS);
+	nonAssignmentOperators->emplace_back(&AS_MINUS_MINUS);
+	nonAssignmentOperators->emplace_back(&AS_NOT_EQUAL);
+	nonAssignmentOperators->emplace_back(&AS_GR_EQUAL);
+	nonAssignmentOperators->emplace_back(&AS_GR_GR_GR);
+	nonAssignmentOperators->emplace_back(&AS_GR_GR);
+	nonAssignmentOperators->emplace_back(&AS_LS_EQUAL);
+	nonAssignmentOperators->emplace_back(&AS_LS_LS_LS);
+	nonAssignmentOperators->emplace_back(&AS_LS_LS);
+	nonAssignmentOperators->emplace_back(&AS_ARROW);
+	nonAssignmentOperators->emplace_back(&AS_AND);
+	nonAssignmentOperators->emplace_back(&AS_OR);
+	nonAssignmentOperators->emplace_back(&AS_LAMBDA);
+
+	assert(nonAssignmentOperators->size() < elements);
 	sort(nonAssignmentOperators->begin(), nonAssignmentOperators->end(), sortOnLength);
 }
 
@@ -358,45 +407,55 @@ void ASResource::buildNonAssignmentOperators(vector<const string*>* nonAssignmen
  */
 void ASResource::buildNonParenHeaders(vector<const string*>* nonParenHeaders, int fileType, bool beautifier)
 {
-	nonParenHeaders->push_back(&AS_ELSE);
-	nonParenHeaders->push_back(&AS_DO);
-	nonParenHeaders->push_back(&AS_TRY);
-	nonParenHeaders->push_back(&AS_CATCH);		// can be paren or non-paren
-	nonParenHeaders->push_back(&AS_CASE);		// can be paren or non-paren
-	nonParenHeaders->push_back(&AS_DEFAULT);
-	nonParenHeaders->push_back(&AS_QFOREVER);	// QT
-	nonParenHeaders->push_back(&AS_FOREVER);	// Boost
+	const size_t elements = 20;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		nonParenHeaders->reserve(elements);
+		reserved = true;
+	}
+
+	nonParenHeaders->emplace_back(&AS_ELSE);
+	nonParenHeaders->emplace_back(&AS_DO);
+	nonParenHeaders->emplace_back(&AS_TRY);
+	nonParenHeaders->emplace_back(&AS_CATCH);		// can be paren or non-paren
+	nonParenHeaders->emplace_back(&AS_CASE);		// can be paren or non-paren
+	nonParenHeaders->emplace_back(&AS_DEFAULT);
+	nonParenHeaders->emplace_back(&AS_QFOREVER);	// QT
+	nonParenHeaders->emplace_back(&AS_FOREVER);	// Boost
 
 	if (fileType == C_TYPE)
 	{
-		nonParenHeaders->push_back(&_AS_TRY);		// __try
-		nonParenHeaders->push_back(&_AS_FINALLY);	// __finally
+		nonParenHeaders->emplace_back(&_AS_TRY);		// __try
+		nonParenHeaders->emplace_back(&_AS_FINALLY);	// __finally
 	}
 	if (fileType == JAVA_TYPE)
 	{
-		nonParenHeaders->push_back(&AS_FINALLY);
+		nonParenHeaders->emplace_back(&AS_FINALLY);
 	}
 
 	if (fileType == SHARP_TYPE)
 	{
-		nonParenHeaders->push_back(&AS_FINALLY);
-		nonParenHeaders->push_back(&AS_GET);
-		nonParenHeaders->push_back(&AS_SET);
-		nonParenHeaders->push_back(&AS_ADD);
-		nonParenHeaders->push_back(&AS_REMOVE);
+		nonParenHeaders->emplace_back(&AS_FINALLY);
+		nonParenHeaders->emplace_back(&AS_GET);
+		nonParenHeaders->emplace_back(&AS_SET);
+		nonParenHeaders->emplace_back(&AS_ADD);
+		nonParenHeaders->emplace_back(&AS_REMOVE);
 	}
 
 	if (beautifier)
 	{
 		if (fileType == C_TYPE)
 		{
-			nonParenHeaders->push_back(&AS_TEMPLATE);
+			nonParenHeaders->emplace_back(&AS_TEMPLATE);
 		}
 		if (fileType == JAVA_TYPE)
 		{
-			nonParenHeaders->push_back(&AS_STATIC);
+			nonParenHeaders->emplace_back(&AS_STATIC);
 		}
 	}
+
+	assert(nonParenHeaders->size() < elements);
 	sort(nonParenHeaders->begin(), nonParenHeaders->end(), sortOnName);
 }
 
@@ -408,54 +467,65 @@ void ASResource::buildNonParenHeaders(vector<const string*>* nonParenHeaders, in
  */
 void ASResource::buildOperators(vector<const string*>* operators, int fileType)
 {
-	operators->push_back(&AS_PLUS_ASSIGN);
-	operators->push_back(&AS_MINUS_ASSIGN);
-	operators->push_back(&AS_MULT_ASSIGN);
-	operators->push_back(&AS_DIV_ASSIGN);
-	operators->push_back(&AS_MOD_ASSIGN);
-	operators->push_back(&AS_OR_ASSIGN);
-	operators->push_back(&AS_AND_ASSIGN);
-	operators->push_back(&AS_XOR_ASSIGN);
-	operators->push_back(&AS_EQUAL);
-	operators->push_back(&AS_PLUS_PLUS);
-	operators->push_back(&AS_MINUS_MINUS);
-	operators->push_back(&AS_NOT_EQUAL);
-	operators->push_back(&AS_GR_EQUAL);
-	operators->push_back(&AS_GR_GR_GR_ASSIGN);
-	operators->push_back(&AS_GR_GR_ASSIGN);
-	operators->push_back(&AS_GR_GR_GR);
-	operators->push_back(&AS_GR_GR);
-	operators->push_back(&AS_LS_EQUAL);
-	operators->push_back(&AS_LS_LS_LS_ASSIGN);
-	operators->push_back(&AS_LS_LS_ASSIGN);
-	operators->push_back(&AS_LS_LS_LS);
-	operators->push_back(&AS_LS_LS);
-	operators->push_back(&AS_QUESTION_QUESTION);
-	operators->push_back(&AS_LAMBDA);
-	operators->push_back(&AS_ARROW);
-	operators->push_back(&AS_AND);
-	operators->push_back(&AS_OR);
-	operators->push_back(&AS_SCOPE_RESOLUTION);
-	operators->push_back(&AS_PLUS);
-	operators->push_back(&AS_MINUS);
-	operators->push_back(&AS_MULT);
-	operators->push_back(&AS_DIV);
-	operators->push_back(&AS_MOD);
-	operators->push_back(&AS_QUESTION);
-	operators->push_back(&AS_COLON);
-	operators->push_back(&AS_ASSIGN);
-	operators->push_back(&AS_LS);
-	operators->push_back(&AS_GR);
-	operators->push_back(&AS_NOT);
-	operators->push_back(&AS_BIT_OR);
-	operators->push_back(&AS_BIT_AND);
-	operators->push_back(&AS_BIT_NOT);
-	operators->push_back(&AS_BIT_XOR);
+	const size_t elements = 50;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		operators->reserve(elements);
+		reserved = true;
+	}
+
+
+	operators->emplace_back(&AS_PLUS_ASSIGN);
+	operators->emplace_back(&AS_MINUS_ASSIGN);
+	operators->emplace_back(&AS_MULT_ASSIGN);
+	operators->emplace_back(&AS_DIV_ASSIGN);
+	operators->emplace_back(&AS_MOD_ASSIGN);
+	operators->emplace_back(&AS_OR_ASSIGN);
+	operators->emplace_back(&AS_AND_ASSIGN);
+	operators->emplace_back(&AS_XOR_ASSIGN);
+	operators->emplace_back(&AS_EQUAL);
+	operators->emplace_back(&AS_PLUS_PLUS);
+	operators->emplace_back(&AS_MINUS_MINUS);
+	operators->emplace_back(&AS_NOT_EQUAL);
+	operators->emplace_back(&AS_GR_EQUAL);
+	operators->emplace_back(&AS_GR_GR_GR_ASSIGN);
+	operators->emplace_back(&AS_GR_GR_ASSIGN);
+	operators->emplace_back(&AS_GR_GR_GR);
+	operators->emplace_back(&AS_GR_GR);
+	operators->emplace_back(&AS_LS_EQUAL);
+	operators->emplace_back(&AS_LS_LS_LS_ASSIGN);
+	operators->emplace_back(&AS_LS_LS_ASSIGN);
+	operators->emplace_back(&AS_LS_LS_LS);
+	operators->emplace_back(&AS_LS_LS);
+	operators->emplace_back(&AS_QUESTION_QUESTION);
+	operators->emplace_back(&AS_LAMBDA);
+	operators->emplace_back(&AS_ARROW);
+	operators->emplace_back(&AS_AND);
+	operators->emplace_back(&AS_OR);
+	operators->emplace_back(&AS_SCOPE_RESOLUTION);
+	operators->emplace_back(&AS_PLUS);
+	operators->emplace_back(&AS_MINUS);
+	operators->emplace_back(&AS_MULT);
+	operators->emplace_back(&AS_DIV);
+	operators->emplace_back(&AS_MOD);
+	operators->emplace_back(&AS_QUESTION);
+	operators->emplace_back(&AS_COLON);
+	operators->emplace_back(&AS_ASSIGN);
+	operators->emplace_back(&AS_LS);
+	operators->emplace_back(&AS_GR);
+	operators->emplace_back(&AS_NOT);
+	operators->emplace_back(&AS_BIT_OR);
+	operators->emplace_back(&AS_BIT_AND);
+	operators->emplace_back(&AS_BIT_NOT);
+	operators->emplace_back(&AS_BIT_XOR);
 	if (fileType == C_TYPE)
 	{
-		operators->push_back(&AS_GCC_MIN_ASSIGN);
-		operators->push_back(&AS_GCC_MAX_ASSIGN);
+		operators->emplace_back(&AS_GCC_MIN_ASSIGN);
+		operators->emplace_back(&AS_GCC_MAX_ASSIGN);
 	}
+
+	assert(operators->size() < elements);
 	sort(operators->begin(), operators->end(), sortOnLength);
 }
 
@@ -468,27 +538,37 @@ void ASResource::buildOperators(vector<const string*>* operators, int fileType)
  */
 void ASResource::buildPreBlockStatements(vector<const string*>* preBlockStatements, int fileType)
 {
-	preBlockStatements->push_back(&AS_CLASS);
+	const size_t elements = 10;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		preBlockStatements->reserve(elements);
+		reserved = true;
+	}
+
+	preBlockStatements->emplace_back(&AS_CLASS);
 	if (fileType == C_TYPE)
 	{
-		preBlockStatements->push_back(&AS_STRUCT);
-		preBlockStatements->push_back(&AS_UNION);
-		preBlockStatements->push_back(&AS_NAMESPACE);
-		preBlockStatements->push_back(&AS_MODULE);     // for CORBA IDL
-		preBlockStatements->push_back(&AS_INTERFACE);  // for CORBA IDL
+		preBlockStatements->emplace_back(&AS_STRUCT);
+		preBlockStatements->emplace_back(&AS_UNION);
+		preBlockStatements->emplace_back(&AS_NAMESPACE);
+		preBlockStatements->emplace_back(&AS_MODULE);     // for CORBA IDL
+		preBlockStatements->emplace_back(&AS_INTERFACE);  // for CORBA IDL
 	}
 	if (fileType == JAVA_TYPE)
 	{
-		preBlockStatements->push_back(&AS_INTERFACE);
-		preBlockStatements->push_back(&AS_THROWS);
+		preBlockStatements->emplace_back(&AS_INTERFACE);
+		preBlockStatements->emplace_back(&AS_THROWS);
 	}
 	if (fileType == SHARP_TYPE)
 	{
-		preBlockStatements->push_back(&AS_INTERFACE);
-		preBlockStatements->push_back(&AS_NAMESPACE);
-		preBlockStatements->push_back(&AS_WHERE);
-		preBlockStatements->push_back(&AS_STRUCT);
+		preBlockStatements->emplace_back(&AS_INTERFACE);
+		preBlockStatements->emplace_back(&AS_NAMESPACE);
+		preBlockStatements->emplace_back(&AS_WHERE);
+		preBlockStatements->emplace_back(&AS_STRUCT);
 	}
+
+	assert(preBlockStatements->size() < elements);
 	sort(preBlockStatements->begin(), preBlockStatements->end(), sortOnName);
 }
 
@@ -503,27 +583,37 @@ void ASResource::buildPreBlockStatements(vector<const string*>* preBlockStatemen
  */
 void ASResource::buildPreCommandHeaders(vector<const string*>* preCommandHeaders, int fileType)
 {
+	const size_t elements = 10;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		preCommandHeaders->reserve(elements);
+		reserved = true;
+	}
+
 	if (fileType == C_TYPE)
 	{
-		preCommandHeaders->push_back(&AS_CONST);
-		preCommandHeaders->push_back(&AS_VOLATILE);
-		preCommandHeaders->push_back(&AS_INTERRUPT);
-		preCommandHeaders->push_back(&AS_NOEXCEPT);
-		preCommandHeaders->push_back(&AS_OVERRIDE);
-		preCommandHeaders->push_back(&AS_SEALED);			// Visual C only
-		preCommandHeaders->push_back(&AS_AUTORELEASEPOOL);	// Obj-C only
+		preCommandHeaders->emplace_back(&AS_CONST);
+		preCommandHeaders->emplace_back(&AS_FINAL);
+		preCommandHeaders->emplace_back(&AS_INTERRUPT);
+		preCommandHeaders->emplace_back(&AS_NOEXCEPT);
+		preCommandHeaders->emplace_back(&AS_OVERRIDE);
+		preCommandHeaders->emplace_back(&AS_VOLATILE);
+		preCommandHeaders->emplace_back(&AS_SEALED);			// Visual C only
+		preCommandHeaders->emplace_back(&AS_AUTORELEASEPOOL);	// Obj-C only
 	}
 
 	if (fileType == JAVA_TYPE)
 	{
-		preCommandHeaders->push_back(&AS_THROWS);
+		preCommandHeaders->emplace_back(&AS_THROWS);
 	}
 
 	if (fileType == SHARP_TYPE)
 	{
-		preCommandHeaders->push_back(&AS_WHERE);
+		preCommandHeaders->emplace_back(&AS_WHERE);
 	}
 
+	assert(preCommandHeaders->size() < elements);
 	sort(preCommandHeaders->begin(), preCommandHeaders->end(), sortOnName);
 }
 
@@ -537,25 +627,35 @@ void ASResource::buildPreCommandHeaders(vector<const string*>* preCommandHeaders
  */
 void ASResource::buildPreDefinitionHeaders(vector<const string*>* preDefinitionHeaders, int fileType)
 {
-	preDefinitionHeaders->push_back(&AS_CLASS);
+	const size_t elements = 10;
+	static bool reserved = false;
+	if (!reserved)
+	{
+		preDefinitionHeaders->reserve(elements);
+		reserved = true;
+	}
+
+	preDefinitionHeaders->emplace_back(&AS_CLASS);
 	if (fileType == C_TYPE)
 	{
-		preDefinitionHeaders->push_back(&AS_STRUCT);
-		preDefinitionHeaders->push_back(&AS_UNION);
-		preDefinitionHeaders->push_back(&AS_NAMESPACE);
-		preDefinitionHeaders->push_back(&AS_MODULE);     // for CORBA IDL
-		preDefinitionHeaders->push_back(&AS_INTERFACE);  // for CORBA IDL
+		preDefinitionHeaders->emplace_back(&AS_STRUCT);
+		preDefinitionHeaders->emplace_back(&AS_UNION);
+		preDefinitionHeaders->emplace_back(&AS_NAMESPACE);
+		preDefinitionHeaders->emplace_back(&AS_MODULE);     // for CORBA IDL
+		preDefinitionHeaders->emplace_back(&AS_INTERFACE);  // for CORBA IDL
 	}
 	if (fileType == JAVA_TYPE)
 	{
-		preDefinitionHeaders->push_back(&AS_INTERFACE);
+		preDefinitionHeaders->emplace_back(&AS_INTERFACE);
 	}
 	if (fileType == SHARP_TYPE)
 	{
-		preDefinitionHeaders->push_back(&AS_STRUCT);
-		preDefinitionHeaders->push_back(&AS_INTERFACE);
-		preDefinitionHeaders->push_back(&AS_NAMESPACE);
+		preDefinitionHeaders->emplace_back(&AS_STRUCT);
+		preDefinitionHeaders->emplace_back(&AS_INTERFACE);
+		preDefinitionHeaders->emplace_back(&AS_NAMESPACE);
 	}
+
+	assert(preDefinitionHeaders->size() < elements);
 	sort(preDefinitionHeaders->begin(), preDefinitionHeaders->end(), sortOnName);
 }
 
@@ -563,6 +663,46 @@ void ASResource::buildPreDefinitionHeaders(vector<const string*>* preDefinitionH
  *                             ASBase Functions
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+// check if a specific line position contains a header.
+const string* ASBase::findHeader(const string& line, int i,
+                                 const vector<const string*>* possibleHeaders) const
+{
+	assert(isCharPotentialHeader(line, i));
+	// check the word
+	size_t maxHeaders = possibleHeaders->size();
+	for (size_t p = 0; p < maxHeaders; p++)
+	{
+		const string* header = (*possibleHeaders)[p];
+		const size_t wordEnd = i + header->length();
+		if (wordEnd > line.length())
+			continue;
+		int result = (line.compare(i, header->length(), *header));
+		if (result > 0)
+			continue;
+		if (result < 0)
+			break;
+		// check that this is not part of a longer word
+		if (wordEnd == line.length())
+			return header;
+		if (isLegalNameChar(line[wordEnd]))
+			continue;
+		const char peekChar = peekNextChar(line, wordEnd - 1);
+		// is not a header if part of a definition
+		if (peekChar == ',' || peekChar == ')')
+			break;
+		// the following accessor definitions are NOT headers
+		// goto default; is NOT a header
+		// default(int) keyword in C# is NOT a header
+		else if ((header == &AS_GET
+		          || header == &AS_SET
+		          || header == &AS_DEFAULT)
+		         && (peekChar == ';' || peekChar == '(' || peekChar == '='))
+			break;
+		return header;
+	}
+	return nullptr;
+}
+
 // check if a specific line position contains a keyword.
 bool ASBase::findKeyword(const string& line, int i, const string& keyword) const
 {
@@ -580,12 +720,32 @@ bool ASBase::findKeyword(const string& line, int i, const string& keyword) const
 	if (isLegalNameChar(line[wordEnd]))
 		return false;
 	// is not a keyword if part of a definition
-	const char peekChar = peekNextChar(line, (int)wordEnd - 1);
+	const char peekChar = peekNextChar(line, (int) wordEnd - 1);
 	if (peekChar == ',' || peekChar == ')')
 		return false;
 	return true;
 }
 
+// check if a specific line position contains an operator.
+const string* ASBase::findOperator(const string& line, int i,
+                                   const vector<const string*>* possibleOperators) const
+{
+	assert(isCharPotentialOperator(line[i]));
+	// find the operator in the vector
+	// the vector contains the LONGEST operators first
+	// must loop thru the entire vector
+	size_t maxOperators = possibleOperators->size();
+	for (size_t p = 0; p < maxOperators; p++)
+	{
+		const size_t wordEnd = i + (*(*possibleOperators)[p]).length();
+		if (wordEnd > line.length())
+			continue;
+		if (line.compare(i, (*(*possibleOperators)[p]).length(), *(*possibleOperators)[p]) == 0)
+			return (*possibleOperators)[p];
+	}
+	return nullptr;
+}
+
 // get the current word on a line
 // index must point to the beginning of the word
 string ASBase::getCurrentWord(const string& line, size_t index) const
