@@ -39,7 +39,6 @@ HtmlGenerator::HtmlGenerator () :
     CodeGenerator ( HTML ),
     brTag ( "<br>" ),
     hrTag ( "<hr>" ),
-    idAttr ( "name" ),
     fileSuffix ( ".html" ),
     cssClassName ( "hl" ),
     orderedList ( false ),
@@ -213,9 +212,13 @@ string  HtmlGenerator::getOpenTag ( const ElementStyle & elem )
 string HtmlGenerator::getGeneratorComment()
 {
     ostringstream s;
-    s <<"\n</body>\n</html>\n<!--HTML generated by highlight "
-      << HIGHLIGHT_VERSION << ", " <<  HIGHLIGHT_URL <<"-->\n";
-
+    s << "\n</body>\n</html>\n";
+    
+    if (!omitVersionComment) {
+        s << "<!--HTML generated by highlight "
+          << HIGHLIGHT_VERSION << ", " <<  HIGHLIGHT_URL <<"-->\n";     
+    }
+   
     return s.str();
 }
 
@@ -334,10 +337,21 @@ void HtmlGenerator::insertLineNumber ( bool insertNewLine )
     if ( showLineNumbers ) {
         ostringstream numberPrefix;
         int lineNo = lineNumber+lineNumberOffset;
+
+        string lineID;
+        //attach Anchor only if we're in a new line.
+        if ( attachAnchors && numberCurrentLine ) {
+            ostringstream idStream;
+            idStream << " id=\"" << anchorPrefix << "_" << lineNo << "\"";
+            lineID = idStream.str();
+        }
+
         if ( orderedList ) {
             if ( useInlineCSS ) {
                 bool quoteFont=getBaseFont().find_first_of(",'")==string::npos;
-                numberPrefix<< "<li style=\""
+                numberPrefix<< "<li"
+                            << lineID
+                            << " style=\""
                             << getAttributes ( "", docStyle.getLineStyle() )
                             << "; font-size:" << this->getBaseFontSize()
                             << "pt; font-family:"<<((quoteFont)?"'":"")
@@ -345,25 +359,18 @@ void HtmlGenerator::insertLineNumber ( bool insertNewLine )
                             << ";\">";
             } else {
                 if (!cssClassName.empty())
-                    numberPrefix<<"<li class=\""<<cssClassName<<"\">";
+                    numberPrefix<<"<li"
+                                << lineID
+                                << " class=\""<<cssClassName<<"\">";
                 else
-                    numberPrefix<<"<li>";
+                    numberPrefix<<"<li"
+                                << lineID
+                                << ">";
             }
             // Opera 8 ignores empty list items -> add &nbsp;
             //if ( line.empty() ) numberPrefix<<"&nbsp;";
         }
 
-        //attach Anchor only if we're in a new line.
-        if ( attachAnchors && numberCurrentLine ) {
-            numberPrefix << "<a "
-                         << idAttr
-                         << "=\""
-                         << anchorPrefix
-                         << "_"
-                         << lineNo
-                         << "\"></a>";
-        }
-
         if ( !orderedList ) {
             //if we're in a wrapped line, don't fill with zeroes.
             ostringstream os;
@@ -379,7 +386,8 @@ void HtmlGenerator::insertLineNumber ( bool insertNewLine )
                 os << "";
             }
 
-            numberPrefix << openTags[LINENUMBER]
+            string tagOpen=openTags[LINENUMBER];
+            numberPrefix << tagOpen.insert(tagOpen.size()-1, lineID)
                          << os.str()
                          << spacer
                          << closeTags[LINENUMBER];
@@ -401,9 +409,10 @@ bool HtmlGenerator::printIndexFile ( const vector<string> &fileList,
         string inFilePath, newInFilePath;
         std::set<string> usedFileNames;
         indexfile << getHeaderStart ( "Source Index" );
-        indexfile << "</head>\n<body>\n<h1> Source Index</h1>\n"
+        indexfile << "</head>\n<body>\n<h1>Source Index</h1>\n"
                   << hrTag
                   <<  "\n<ul>\n";
+                  
         string::size_type pos;
         for ( unsigned int i=0; i < fileList.size();  i++ ) {
             pos= ( fileList[i] ).find_last_of ( Platform::pathSeparator );
@@ -432,13 +441,14 @@ bool HtmlGenerator::printIndexFile ( const vector<string> &fileList,
             indexfile << inFileName << suffix <<"</a></li>\n";
         }
 
-        indexfile << "</ul>\n"
-                  << hrTag << brTag
-                  << "<small>Generated by highlight "
-                  << HIGHLIGHT_VERSION
-                  << ", <a href=\"" << HIGHLIGHT_URL << "\" target=\"new\">"
-                  << HIGHLIGHT_URL << "</a></small>";
-        indexfile << getGeneratorComment();
+        indexfile << "</ul>\n";
+        if (!omitVersionComment) {
+            indexfile << hrTag << brTag
+                    << "<small>Generated by highlight "
+                    << HIGHLIGHT_VERSION
+                    << ", <a href=\"" << HIGHLIGHT_URL << "\" target=\"new\">"
+                    << HIGHLIGHT_URL << "</a></small>";
+        }
     } else {
         return false;
     }
