@@ -156,12 +156,15 @@ string LatexGenerator::getFooter()
     if (beamerMode)
       os  << "}\n";
 
-    os << "\\end {document}\n"
-       << "(* LaTeX generated by highlight "
+    os << "\\end {document}\n";
+    
+    if (!omitVersionComment) {
+     os  << "(* LaTeX generated by highlight "
        << HIGHLIGHT_VERSION
        << ", "
        << HIGHLIGHT_URL
        << " *)\n";
+    }
     return os.str();
 }
 
