@@ -46,7 +46,7 @@ RtfGenerator::RtfGenerator()
 {
     newLineTag = "}\\par\\pard\n\\cbpat1{";
     spacer = " ";
-   
+
     // Page dimensions
     psMap["a3"] = PageSize ( 16837,23811 );
     psMap["a4"] = PageSize ( 11905,16837 );
@@ -124,9 +124,9 @@ string RtfGenerator::getCharStyle ( int styleNumber,const ElementStyle &elem,
 
 void RtfGenerator::printBody()
 {
-  isUtf8 = StringTools::change_case ( encoding ) == "utf-8";
-  
-  *out << "{\\rtf1\\ansi \\deff1" // drop \\uc0 because of unicode output
+    isUtf8 = StringTools::change_case ( encoding ) == "utf-8";
+
+    *out << "{\\rtf1\\ansi \\deff1" // drop \\uc0 because of unicode output
          << "{\\fonttbl{\\f1\\fmodern\\fprq1\\fcharset0 " ;
     *out << this->getBaseFont() ;
     *out << ";}}"
@@ -163,7 +163,12 @@ void RtfGenerator::printBody()
        on the order. We access the keyword style with an ID, which is calculated
        ignoring the alphabetic order.
     */
+    
+    ///FIXME: nested syntax may be highlighted incorrectly if it contains more 
+    //        keyword definitions than the hosting syntax.
+    //        Workaround: Add keyword gruop to hosting syntax (see html.lang)
     vector<string>  keywordClasses = currentSyntax->getKeywordClasses();
+        
     for ( unsigned int i=0; i<keywordClasses.size(); i++ ) {
         *out << getAttributes ( docStyle.getKeywordStyle ( keywordClasses[i] ) );
     }
@@ -190,12 +195,12 @@ void RtfGenerator::printBody()
         }
         *out << "}}\n";
     }
-    
+
     if (addPageColor) {
-      long svVal =  docStyle.getBgColour().getRed() +  
-                    docStyle.getBgColour().getGreen() * 256+ 
-                    docStyle.getBgColour().getBlue() * 256 * 256;
-                    *out<<"\\viewbksp1\\ilfomacatclnup0{\\*\\background{\\shp{{\\sp{\\sn fillColor}{\\sv "<<svVal<<"}}}}}\n";
+        long svVal =  docStyle.getBgColour().getRed() +
+                      docStyle.getBgColour().getGreen() * 256+
+                      docStyle.getBgColour().getBlue() * 256 * 256;
+        *out<<"\\viewbksp1\\ilfomacatclnup0{\\*\\background{\\shp{{\\sp{\\sn fillColor}{\\sv "<<svVal<<"}}}}}\n";
     }
 
     *out  << "\\paperw"<< psMap[pageSize].width <<"\\paperh"<< psMap[pageSize].height
@@ -244,55 +249,50 @@ void RtfGenerator::initOutputTags ( )
 }
 
 string RtfGenerator::maskCharacter ( unsigned char c )
-{  
-  if (isUtf8 && c > 0x7f  && utf8SeqLen==0){
-    
-    //http://stackoverflow.com/questions/7153935/how-to-convert-utf-8-stdstring-to-utf-16-stdwstring
-    
-    if (c <= 0xDF)
-    {
-      utf16Char = c&0x1F;
-      utf8SeqLen = 1;
-    }
-    else if (c <= 0xEF)
-    {
-      utf16Char = c&0x0F;
-      utf8SeqLen = 2;
-    }
-    else if (c <= 0xF7)
-    {
-      utf16Char = c&0x07;
-      utf8SeqLen = 3;
-    } else {
-      utf8SeqLen = 0;
-    }
-    return "";
-  }
-  
-  if (utf8SeqLen) {
-      utf16Char <<= 6;
-      utf16Char += c & 0x3f;   
-      --utf8SeqLen;
-    
-      if (!utf8SeqLen){
-        string m ( "\\u" );
-        m += to_string(utf16Char);
-        m += '?';
-        utf16Char=0L;
-        return m;
-      } else {
+{
+    if (isUtf8 && c > 0x7f  && utf8SeqLen==0) {
+
+        //http://stackoverflow.com/questions/7153935/how-to-convert-utf-8-stdstring-to-utf-16-stdwstring
+
+        if (c <= 0xDF) {
+            utf16Char = c&0x1F;
+            utf8SeqLen = 1;
+        } else if (c <= 0xEF) {
+            utf16Char = c&0x0F;
+            utf8SeqLen = 2;
+        } else if (c <= 0xF7) {
+            utf16Char = c&0x07;
+            utf8SeqLen = 3;
+        } else {
+            utf8SeqLen = 0;
+        }
         return "";
-      }
-  }
-  
-  switch ( c ) {
+    }
+
+    if (utf8SeqLen) {
+        utf16Char <<= 6;
+        utf16Char += c & 0x3f;
+        --utf8SeqLen;
+
+        if (!utf8SeqLen) {
+            string m ( "\\u" );
+            m += to_string(utf16Char);
+            m += '?';
+            utf16Char=0L;
+            return m;
+        } else {
+            return "";
+        }
+    }
+
+    switch ( c ) {
     case '}' :
     case '{' :
     case '\\' : {
-          string m ( "\\" );
-          return m += c;
-        }
-        break;
+        string m ( "\\" );
+        return m += c;
+    }
+    break;
     case '0':
     case '1':
     case '2':
@@ -303,12 +303,12 @@ string RtfGenerator::maskCharacter ( unsigned char c )
     case '7':
     case '8':
     case '9': {
-          string m ( 1, '{' );
-          m += c;
-          m += '}';
-          return m;
-        }
-        break;
+        string m ( 1, '{' );
+        m += c;
+        m += '}';
+        return m;
+    }
+    break;
 
     case AUML_LC:
         return "\\'e4";
@@ -412,7 +412,7 @@ void RtfGenerator::setRTFCharStyles ( bool cs )
 
 void RtfGenerator::setRTFPageColor ( bool pc )
 {
-  addPageColor = pc;
+    addPageColor = pc;
 }
 
 
