@@ -121,4 +121,11 @@ string getPathAcronym(const string&path, char delim)
     return acronym;
 }
 
+
+bool endsWith(std::string const & value, std::string const & ending)
+{
+    if (ending.size() > value.size()) return false;
+    return std::equal(ending.rbegin(), ending.rend(), value.rbegin());
+}
+
 }
