@@ -118,12 +118,14 @@ void TexGenerator::printBody()
 string TexGenerator::getFooter()
 {
     ostringstream os;
-    os << "\\bye\n"
-       << "% TeX generated by Highlight "
-       << HIGHLIGHT_VERSION
-       << ", "
-       << HIGHLIGHT_URL
-       << endl;
+    os << "\\bye\n";
+    
+    if (!omitVersionComment) {
+        os  << "% TeX generated by Highlight "
+            << HIGHLIGHT_VERSION
+            << ", "
+            << HIGHLIGHT_URL << "\n";
+    }
     return os.str();
 }
 
