@@ -117,6 +117,13 @@ private:
     /** flag to add page color */
     bool addPageColor;
     
+    /** flag to enable Unicode conversion */
+    bool isUtf8;
+    
+    /** utf-8 to utf-16 conversion variables */
+    unsigned long utf16Char;
+    size_t utf8SeqLen;
+    
     /** @return escaped character*/
     virtual string maskCharacter ( unsigned char );
 
